==> je-1.5.3.tar.gz: je-1.5.3/test/com/sleepycat/je/EnvironmentStatTest.java <==
/*-
* See the file LICENSE for redistribution information.
*
* Copyright (c) 2002-2004
*      Sleepycat Software.  All rights reserved.
*
* $Id: EnvironmentStatTest.java,v 1.9 2004/08/21 02:05:39 linda Exp $
*/

package com.sleepycat.je;

import java.io.File;
import java.io.IOException;

import junit.framework.TestCase;

import com.sleepycat.je.config.EnvironmentParams;
import com.sleepycat.je.dbi.MemoryBudget;
import com.sleepycat.je.util.TestUtils;

public class EnvironmentStatTest extends TestCase {

    private Environment env;
    private File envHome;

    public EnvironmentStatTest() {
        envHome = new File(System.getProperty("testdestdir"));
    }

    public void setUp()
        throws IOException {

        TestUtils.removeLogFiles("Setup", envHome, false);
    }
    
    public void tearDown()
        throws Exception {

        /* Close down environments in case the unit test failed so that
         * the log files can be removed. 
         */
        try {
            if (env != null) {
                env.close();
                env = null;
            }
        } catch (DatabaseException e) {
            /* ok, the test closed it */
        }

        TestUtils.removeLogFiles("TearDown", envHome, false);
    }

    /**
     * Test open and close of an environment.
     */
    public void testCacheStats()
        throws Throwable {

        try {
            EnvironmentConfig envConfig = new EnvironmentConfig();
            envConfig.setTransactional(true);
            envConfig.setConfigParam(EnvironmentParams.NODE_MAX.getName(), "6");
            envConfig.setAllowCreate(true);
            env = new Environment(envHome, envConfig);
            EnvironmentStats stat = env.getStats(TestUtils.FAST_STATS);
            env.close();
            env = null;
            assertEquals(0, stat.getNCacheMiss());
            assertEquals(0, stat.getNNotResident());

            // Try to open and close again, now that the environment exists
            envConfig.setAllowCreate(false);
            env = new Environment(envHome, envConfig);
            stat = env.getStats(TestUtils.FAST_STATS);
            MemoryBudget mb =
                DbInternal.envGetEnvironmentImpl(env).getMemoryBudget();
            long cacheSize = mb.getCacheMemoryUsage();
            long bufferSize = mb.getLogBufferBudget();
            
            assertEquals(11, stat.getNCacheMiss());
            assertEquals(11, stat.getNNotResident());

            assertEquals(cacheSize, stat.getCacheDataBytes());

            /* 
             * Buffer size may be slightly different, because the log
             * buffer pool might do some rounding. Just check that
             * it's within an ok margin.
             */
            assertTrue(Math.abs(bufferSize-stat.getBufferBytes()) < 100);
            assertTrue(Math.abs((cacheSize + bufferSize)-
                                stat.getCacheTotalBytes()) < 100);
	    env.close();
        } catch (Throwable t) {
            t.printStackTrace();
            throw t;
        }
    }
}

==> je-2.1.30.tar.gz: je-2.1.30/test/com/sleepycat/je/EnvironmentStatTest.java <==
/*-
 * See the file LICENSE for redistribution information.
 *
 * Copyright (c) 2002-2006
 *      Sleepycat Software.  All rights reserved.
 *
 * $Id: EnvironmentStatTest.java,v 1.15 2006/01/03 21:56:11 bostic Exp $
 */

package com.sleepycat.je;

import java.io.File;
import java.io.IOException;

import junit.framework.TestCase;

import com.sleepycat.je.config.EnvironmentParams;
import com.sleepycat.je.dbi.MemoryBudget;
import com.sleepycat.je.util.TestUtils;

public class EnvironmentStatTest extends TestCase {

    private Environment env;
    private File envHome;

    public EnvironmentStatTest() {
        envHome = new File(System.getProperty(TestUtils.DEST_DIR));
    }

    public void setUp()
        throws IOException {

        TestUtils.removeLogFiles("Setup", envHome, false);
    }
    
    public void tearDown()
        throws Exception {

        /* Close down environments in case the unit test failed so that
         * the log files can be removed. 
         */
        try {
            if (env != null) {
                env.close();
                env = null;
            }
        } catch (DatabaseException e) {
            /* ok, the test closed it */
        }

        TestUtils.removeLogFiles("TearDown", envHome, false);
    }

    /**
     * Test open and close of an environment.
     */
    public void testCacheStats()
        throws Throwable {

        try {
            EnvironmentConfig envConfig = TestUtils.initEnvConfig();
            envConfig.setTransactional(true);
            envConfig.setConfigParam(EnvironmentParams.NODE_MAX.getName(), "6");
            envConfig.setAllowCreate(true);
            env = new Environment(envHome, envConfig);
            EnvironmentStats stat = env.getStats(TestUtils.FAST_STATS);
            env.close();
            env = null;
            assertEquals(0, stat.getNCacheMiss());
            assertEquals(0, stat.getNNotResident());

            // Try to open and close again, now that the environment exists
            envConfig.setAllowCreate(false);
	    envConfig.setConfigParam
		(EnvironmentParams.JE_LOGGING_LEVEL.getName(), "CONFIG");
            env = new Environment(envHome, envConfig);
            stat = env.getStats(TestUtils.FAST_STATS);
            MemoryBudget mb =
                DbInternal.envGetEnvironmentImpl(env).getMemoryBudget();
            long cacheSize = mb.getCacheMemoryUsage();
            long bufferSize = mb.getLogBufferBudget();
            
            assertEquals(12, stat.getNCacheMiss());
            assertEquals(12, stat.getNNotResident());

            assertEquals(cacheSize, stat.getCacheDataBytes());

            /* 
             * Buffer size may be slightly different, because the log
             * buffer pool might do some rounding. Just check that
             * it's within an ok margin.
             */
            assertTrue(Math.abs(bufferSize-stat.getBufferBytes()) < 100);
            assertTrue(Math.abs((cacheSize + bufferSize)-
                                stat.getCacheTotalBytes()) < 100);
	    env.close();
        } catch (Throwable t) {
            t.printStackTrace();
            throw t;
        }
    }
}
